@@ -201,7 +201,7 @@ def load_jinja():
     #: default filters
     jinja.filters.update({
         'xmldatetime': lambda o: o.strftime('%Y-%m-%dT%H:%M:%SZ'),
-        'permalink': lambda o: '/' + get_post_slug(o, settings.permalink),
+        'permalink': permalink,
     })
 
     #: load resource
@@ -234,6 +234,9 @@ def get_post_slug(post, slug_format):
 
     slug = regex.sub(replace, slug_format)
     slug = slug.lstrip('/').replace('//', '/').replace(' ', '-')
+    prefix = settings.site.get('prefix', '').rstrip('/')
+    if prefix:
+        return '%s/%s' % (prefix, slug)
     return slug
 
 
@@ -247,6 +250,13 @@ def slug_to_destination(slug, use_index=False):
     return slug.rstrip('/') + '.html'
 
 
+def permalink(post, prepend_site=False):
+    slug = get_post_slug(post, settings.permalink)
+    if prepend_site:
+        return '%s/%s' % (settings.site['url'].rstrip('/'), slug)
+    return '/%s' % slug
+
+
 def content_url(base, *args):
     def fix_index(url):
         if url.endswith('/index.html'):
@@ -262,7 +272,7 @@ def content_url(base, *args):
         prefix = '/'
         args.insert(0, base)
 
-    args = map(lambda o: o.strip('/'), args)
+    args = map(lambda o: to_unicode(o).strip('/'), args)
     url = '/'.join(args).replace('//', '/').replace(' ', '-')
     url = prefix + url.lstrip('/')
     url = to_unicode(fix_index(url.lower()))
